int OLDHEAP_Init(tAllocatorHeap* heap);
int OLDHEAP_ISHANDLE(tAllocatorHeap* heap, tOBREF h);
int OLDHEAP_SweepAndCompact(tAllocatorHeap* heap);
int OLDHEAP_TestBitfield(tAllocatorHeap* heap);
